Module process

Module process 

Start a process via pty

Structs

PtyProcess
Start a process in a forked tty to interact with it like you would within a terminal

Enums

Signal
Types of operating system signals
WaitStatus
Possible return values from wait() or waitpid().